PyXMake Developer Guide: PyXMake.VTL.cxx Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.cxx Namespace Reference

## Functions
| main (BuildID, files=__mcd_muesli_files, command=VTL.GetBuildCommand(3), libs=VTL.GetLinkDependency(3, 7, __arch), source=__mcd_muesli_src, include=__mcd_muesli_include, dependency=[], output=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), architecture=__arch, scratch=VTL.Scratch, verbosity=2, incremental=True, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Muesli for MCODAC under Windows.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.cxx.main | ( |  | BuildID,
|  |  | files = __mcd_muesli_files,
|  |  | command = VTL.GetBuildCommand(3),
|  |  | libs = VTL.GetLinkDependency(3, 7, __arch),
|  |  | source = __mcd_muesli_src,
|  |  | include = __mcd_muesli_include,
|  |  | dependency = [],
|  |  | output = os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch),
|  |  | architecture = __arch,
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  |  | incremental = True,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 62 of file cxx.py.